@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef BTSTRINGMGR_H
 #define BTSTRINGMGR_H
@@ -22,18 +31,18 @@ public:
 	/** Converts the param to an upper case Utf8 string
 	* @param The text encoded in utf8 which should be turned into an upper case string
 	*/
-	virtual char* upperUTF8(char*, const unsigned int maxlen = 0);
+	virtual char *upperUTF8(char *text, unsigned int max = 0) const;
 
 	/** Converts the param to an uppercase latin1 string
 	* @param The text encoded in latin1 which should be turned into an upper case string
 	*/
-	virtual char* upperLatin1(char*);
-
+	virtual char *upperLatin1(char *text, unsigned int max = 0) const;
+	
 protected:
 	/** Enable Unicode support.
 	* Reimplementation to show unicode support.
 	*/
-	virtual const bool supportsUnicode() const;
+	virtual bool supportsUnicode() const;
 
 	/** CODE TAKEN FROM KDELIBS 3.2, which is licensed under the LGPL 2.
 	*
@@ -42,7 +51,7 @@ protected:
 	* This function checks whether a string is utf8 or not.
 	* It was taken from kdelibs so we do not depend on KDE 3.2.
 	*/
-	const bool isUtf8(const char *buf);
+	const bool isUtf8(const char *buf) const;
 };
 
 #endif
