@@ -26,7 +26,6 @@ void CDisplayTemplateMgr::init() {
  margin: 0;\
  padding: 0;\
  border-spacing:10px;\
-/* vertical-align:top; */\
 }\
 #content > table th {\
  padding: 0 0 2px 0;\
@@ -56,13 +55,10 @@ a:hover {\
  padding: 2px;\
  vertical-align: middle;\
  text-align: justify;\
-/* line-height: 1.5em; */\
 }\
 td.entry {\
-/* padding: 2px; */\
  vertical-align: top;\
  text-align: justify !important;\
-/* line-height: 1.5em; */\
 }\
 #printer .entry {\
  font-size: 90%;\
@@ -81,13 +77,11 @@ td.entry {\
  vertical-align: middle;\
  text-align: justify;\
  background-color: #E6E4FF;\
-/* line-height: 1.5em; */\
 }\
 .currententry[dir=rtl] {\
  text-align:right !important;\
 }\
 div.currententry {\
-/* vertical-align:middle; */\
 }\
 span.currententry {\
  background-color: #EDEFFF !important;\
@@ -103,7 +97,6 @@ td.entry + td.entry { \
 #bible div.currententry, #bible td.currententry {\
  border: 1px solid #B7B7B7;\
  padding: 2px;\
-/* vertical-align: middle; */\
 }\
 \
 \
@@ -133,8 +126,6 @@ td.entry + td.entry { \
  vertical-align: super;\
 }\
 .entryname a, #printer .entryname {\
-/* vertical-align: middle */\
- /*font-size: 80% !important;*/\
 }\
 \
 #printer .entry .entry, #printer .entry .sectiontitle , #printer .entry .booktitle {\
@@ -154,7 +145,6 @@ td.entry + td.entry { \
 .footnote:after { content:\")\"; }\
 \
 .footnotepre {\
-/* vertical-align: middle; */\
  font-style: italic;\
 }\
 \
@@ -264,6 +254,7 @@ td.entry + td.entry { \
 .name > .ritual {\
 }\
 .name > .divine {\
+ font-variant: small-caps;\
 }\
 \
 .transchange { \
@@ -285,10 +276,6 @@ td.entry + td.entry { \
 \
 .morphSegmentation {\
  border-right: 2px solid grey;\
-/* margin-top: 1px; /* Don`t let the boxes touch here, between the lines */\
-/* margin-left: -1px; /* But here, for better reading of the text, */\
-/* this will only occur within a word consisting of several segments.*/\
-/* margin-right: 0px; */\
 }\
 \
 #infodisplay {\
@@ -615,7 +602,7 @@ so something like .alternative:before { content:\"'\"attr(alternative); } is pos
 .name > .nonhuman { }\
 .name > .person { }\
 .name > .ritual { }\
-.name > .divine { }\
+.name > .divine { font-variant: small-caps; }\
 \
 /* Information added by the translator */\
 .transchange {}\
@@ -922,6 +909,7 @@ td.entry + td.entry { \
 .name > .ritual {\
 }\
 .name > .divine {\
+ font-variant: small-caps;\
 }\
 \
 .transchange { \
@@ -1265,6 +1253,7 @@ td.entry + td.entry { \
 .name > .ritual {\
 }\
 .name > .divine {\
+ font-variant: small-caps;\
 }\
 \
 .transchange { \
@@ -1451,6 +1440,10 @@ span.currententry {\
  font-size: 0.9em;\
 }\
 \
+.name > .divine {\
+ font-variant: small-caps;\
+}\
+\
 .quotation {\
 }\
 .poetry {\
