@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "btinstallmgr.h"
@@ -27,7 +36,7 @@
 
 using namespace sword;
 
-namespace InstallationManager {
+namespace BookshelfManager {
 
 	const QString BTInstallMgr::Tool::LocalConfig::swordConfigFilename() {
 		//  Q_ASSERT( CPointers::backend()->sysconfig );
