@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "coptionsdialog.h"
 #include "cprofile.h"
@@ -57,6 +66,7 @@
 
 //Sword includes
 #include <localemgr.h>
+#include <swlocale.h>
 
 using std::string;
 using std::list;
