@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CPRINTER_H
 #define CPRINTER_H
@@ -26,9 +35,7 @@ class CPrinter : public QObject, public Rendering::CDisplayRendering {
 		Q_OBJECT
 public:
 		CPrinter(
-			QObject *parent,
-			CSwordBackend::DisplayOptions displayOptions = CBTConfig::getDisplayOptionDefaults(),
-			CSwordBackend::FilterOptions filterOptions = CBTConfig::getFilterOptionDefaults()
+			QObject *parent, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions
 		);
 
 		virtual ~CPrinter();
