@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "cswordsetupdialog.h"
 #include "cswordsetupmodulelistview.h"
@@ -8,6 +17,8 @@
 #include "backend/cswordmoduleinfo.h"
 // #include "btinstallmgr.h"
 
+#include "cmanageindiceswidget.h"
+
 #include "util/cresmgr.h"
 #include "util/ctoolclass.h"
 #include "util/scoped_resource.h"
@@ -42,7 +53,7 @@
 
 using namespace sword;
 
-namespace InstallationManager {
+namespace BookshelfManager {
 
 	CSwordSetupDialog::CSwordSetupDialog(QWidget *parent, const char *name )
 : KDialogBase(IconList, i18n("Bookshelf Manager"), Ok, Ok, parent, name, true, true, QString::null, QString::null, QString::null),
@@ -57,6 +68,7 @@ namespace InstallationManager {
 		initSwordConfig();
 		initInstall();
 		initRemove();
+		initManageIndices();
 	}
 
 	void CSwordSetupDialog::initSwordConfig() {
@@ -224,6 +236,17 @@ the module remote installation feature!</b>")
 		populateRemoveModuleListView();
 	}
 
+	void CSwordSetupDialog::initManageIndices()
+	{
+		QFrame* page = m_manageIndiciesPage = addPage(i18n("Manage search indicies"),
+			QString::null, SmallIcon("filefind",32));
+
+		page->setMinimumSize(500,400);
+		QVBoxLayout* box = new QVBoxLayout(page, 4, 4);
+		CManageIndicesWidget* mi = new CManageIndicesWidget(page);
+		box->addWidget(mi);
+	}
+
 	void CSwordSetupDialog::slotOk() {
 		writeSwordConfig();
 		KDialogBase::slotOk();
@@ -470,7 +493,7 @@ the module remote installation feature!</b>")
 		);
 
 		m_progressDialog->progressBar()->setTotalSteps(100);
-		m_progressDialog->setMinimumDuration(0); //sow immediately
+		m_progressDialog->setMinimumDuration(0); //show immediately
 		m_progressDialog->setLabel( i18n("Downloading library information...") );
 
 		if (BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is)) {
@@ -495,11 +518,11 @@ the module remote installation feature!</b>")
 		return success;
 	}
 
-	void CSwordSetupDialog::populateInstallModuleListView( const QString& sourceName ) {
+	bool CSwordSetupDialog::populateInstallModuleListView( const QString& sourceName ) {
 		KApplication::kApplication()->processEvents();
 		Q_ASSERT(m_installModuleListView);
 		if (!m_installModuleListView) { // this may be an update after removing modules
-			return;
+			return false;
 		}
 
 		m_installModuleListView->clear();
@@ -511,7 +534,7 @@ the module remote installation feature!</b>")
 				&& !refreshRemoteModuleCache(sourceName)) {
 			//   qWarning("finish");
 			m_installModuleListView->finish();
-			return;
+			return false;
 		}
 
 		//kind of a hack to provide a pointer to mgr next line
@@ -524,7 +547,7 @@ the module remote installation feature!</b>")
 		Q_ASSERT( BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is) );
 		if (!remote_backend) {
 			m_installModuleListView->finish();
-			return;
+			return false;
 		}
 
 		CSwordBackend* local_backend = CPointers::backend();
@@ -565,12 +588,6 @@ the module remote installation feature!</b>")
 				}
 			}
 
-			//TODO: is this still true?
-			if ((*it)->isLocked() || (*it)->isEncrypted()) { //encrypted modules have no data files on the server
-				//      qWarning("not using encrypted mod");
-			//	continue;
-			}
-
 			//   Q_ASSERT(installedModule);
 			m_installModuleListView->addModule(
 				(*it),
@@ -580,6 +597,7 @@ the module remote installation feature!</b>")
 			);
 		}
 		m_installModuleListView->finish();
+		return true;
 	}
 
 	void CSwordSetupDialog::slot_connectToSource() {
@@ -612,18 +630,20 @@ the module remote installation feature!</b>")
 			connect(m_installModuleListView, SIGNAL(selectedModulesChanged()), SLOT(slot_installModulesChanged()));
 		}
 
-		//code valid for already existing and newly created widgets
-		disconnect( m_installContinueButton, SIGNAL(clicked()), this, SLOT(slot_connectToSource()));
-		connect( m_installContinueButton, SIGNAL(clicked()), this, SLOT(slot_installModules()));
+		if (populateInstallModuleListView( currentInstallSource() ) ){
 
-		populateInstallModuleListView( currentInstallSource() );
-		m_installContinueButton->setText(i18n("Install works"));
-		m_installContinueButton->setEnabled(false);
-
-		m_installWidgetStack->raiseWidget(m_installModuleListPage);
-
-		connect( m_installBackButton, SIGNAL(clicked()), this, SLOT(slot_showInstallSourcePage()));
-		m_installBackButton->setEnabled(true);
+			//code valid for already existing and newly created widgets
+			disconnect( m_installContinueButton, SIGNAL(clicked()), this, SLOT(slot_connectToSource()));
+			connect( m_installContinueButton, SIGNAL(clicked()), this, SLOT(slot_installModules()));
+	
+			m_installContinueButton->setText(i18n("Install works"));
+			m_installContinueButton->setEnabled(false);
+	
+			m_installWidgetStack->raiseWidget(m_installModuleListPage);
+	
+			connect( m_installBackButton, SIGNAL(clicked()), this, SLOT(slot_showInstallSourcePage()));
+			m_installBackButton->setEnabled(true);
+		}
 	}
 
 	void CSwordSetupDialog::slot_installAddSource() {
@@ -706,7 +726,7 @@ the module remote installation feature!</b>")
 			);
 
 			m_progressDialog->progressBar()->setTotalSteps(100 * moduleList.count());
-			m_progressDialog->setMinimumDuration(0); //sow immediately
+			m_progressDialog->setMinimumDuration(0); //show immediately
 
 
 			for ( QStringList::Iterator it = moduleList.begin(); (it != moduleList.end()) && !m_progressDialog->wasCancelled(); ++it, ++m_installedModuleCount ) {
