@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CSWORDSETUPDIALOG_H
 #define CSWORDSETUPDIALOG_H
@@ -25,7 +34,7 @@ class QListView;
 
 class KProgressDialog;
 
-namespace InstallationManager {
+namespace BookshelfManager {
 
 	class CSwordSetupModuleListView;
 
@@ -52,6 +61,7 @@ private:
 		void initSwordConfig();
 		void initInstall();
 		void initRemove();
+		void initManageIndices();
 
 		void writeSwordConfig();
 
@@ -69,6 +79,7 @@ private:
 		bool m_swordSetupChanged;
 
 		QFrame* m_removePage;
+		QFrame* m_manageIndiciesPage;
 
 		QFrame* m_installPage;
 		QWidgetStack* m_installWidgetStack;
@@ -88,7 +99,7 @@ private:
 
 		const bool refreshRemoteModuleCache( const QString& sourceName );
 		void populateRemoveModuleListView();
-		void populateInstallModuleListView(const QString& sourceName);
+		bool populateInstallModuleListView(const QString& sourceName);
 
 		//install module stuff
 		QPushButton* m_installBackButton;
