@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CHTMLWRITEWINDOW_H
 #define CHTMLWRITEWINDOW_H
@@ -23,11 +32,11 @@ public:
 	/**
 	* Store the settings of this window in the given CProfileWindow object.
 	*/
-	virtual void storeProfileSettings( CProfileWindow* );
+	virtual void storeProfileSettings( Profile::CProfileWindow* );
 	/**
 	* Store the settings of this window in the given profile window.
 	*/
-	virtual void applyProfileSettings( CProfileWindow* );
+	virtual void applyProfileSettings( Profile::CProfileWindow* );
 
 	virtual const bool syncAllowed() const;
 
