@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "cmodulechooserbutton.h"
 #include "cmodulechooserbar.h"
@@ -249,11 +258,12 @@ void CModuleChooserButton::updateMenuItems() {
 
 		for (unsigned int i = 0; i < popup->count(); i++) {
 			moduleName = popup->text(popup->idAt(i));
-			module = backend()->findModuleByName( moduleName.left(moduleName.find(" ")) );
-			Q_ASSERT(module);
-			if (!module) {
-				qWarning("Can't find module with name %s", moduleName.latin1());
-			}
+			module = backend()->findModuleByName( moduleName.left(moduleName.findRev(" ")) );
+
+ 			Q_ASSERT(module);
+// 			if (!module) {
+// 				qWarning("Can't find module with name %s", moduleName.latin1());
+// 			}
 
 			bool alreadyChosen = chosenModules.contains( module );
 			if (m_module) {
