@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "cwritewindow.h"
 
@@ -11,6 +20,8 @@
 #include <kmessagebox.h>
 #include <klocale.h>
 
+using namespace Profile;
+
 CWriteWindow::CWriteWindow(ListCSwordModuleInfo modules, CMDIArea* parent, const char *name )
 : CDisplayWindow(modules, parent,name), m_writeDisplay(0) {}
 
