@@ -9,8 +9,8 @@
 
 
 
-/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.138 2006/11/24 20:24:18 joachim Exp $ */
-/* $Revision: 1.138 $ */
+/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.143 2007/04/02 21:53:48 joachim Exp $ */
+/* $Revision: 1.143 $ */
 
 //standard includes
 #include <stdlib.h>
@@ -134,7 +134,7 @@ int main(int argc, char* argv[]) {
 		VERSION,
 		I18N_NOOP("Bible study tool for KDE"),
 		KAboutData::License_GPL_V2,
-		I18N_NOOP("(c)1999-2006, The BibleTime Team"),
+		I18N_NOOP("(c)1999-2007, The BibleTime Team"),
 		I18N_NOOP("BibleTime is an easy to use but powerful Bible study tool for KDE.\n\nWe are looking for developers and translators.\nIf you'd like to join our team, please send an email to info@bibletime.info."),
 		"http://www.bibletime.info/",
 		"info@bibletime.info"
@@ -165,6 +165,12 @@ int main(int argc, char* argv[]) {
 	aboutData.addCredit("Timothy R. Butler", I18N_NOOP("Icons, startlogo"), "tbutler@uninetsolutions.com", "http://www.uninetsolutions.com");
 	//GUI improvements
 	aboutData.addCredit("Jim Campbell",   I18N_NOOP("GUI"), "jdc.email@gmail.com", ""); 
+	//Indexed search, gui improvements
+	aboutData.addCredit("Lee Carpenter",  I18N_NOOP("GUI, instant search"),"Lee Carpenter <elc@carpie.net>", "http://www.carpie.net");
+	//Translations into Traditional and Simplified Chinese
+	aboutData.addCredit("Chun-shek Chan",   I18N_NOOP("GUI translations into Traditional and Simplified Chinese"), "chunshek@gmail.com", "");
+	//Binary packages of CLucene, BibleTime and Sword for Fedore, SUSE, Mandriva
+	aboutData.addCredit("Jeremy Erickson",   I18N_NOOP("Binary packages"), "", "");
 	//Started the Crosswire porject, also contributed some code
 	aboutData.addCredit("Troy A. Griffits",   I18N_NOOP("Founder of the Sword project"), "scribe@crosswire.org", "http://www.crosswire.org/");  
 	//Sponsored many years the www.bibletime.de domain!
@@ -175,8 +181,8 @@ int main(int argc, char* argv[]) {
 	aboutData.addCredit("Nikolay Igotti", I18N_NOOP("Search dialog enhancements"), "olonho@hotmail.com", "");
 	// Language codes iso639-1, iso639-2 and SIL language codes
 	aboutData.addCredit("SIL International", I18N_NOOP("Language codes and names"), "", "http://www.ethnologue.com/iso639");
-	//Indexed search, gui improvements
-	aboutData.addCredit("Lee Carpenter",  I18N_NOOP("GUI, instant search"),"Lee Carpenter <elc@carpie.net>", "http://www.carpie.net");
+	//Patch for the mag delay (2007-03-22)
+	aboutData.addCredit("Eeli Kaikkonen",  I18N_NOOP("GUI improvements"),"eekaikko@mail.student.oulu.fi", "");
 	//Update the the Finnish GUI translation
 	aboutData.addCredit("Ilpo Kantonen",  I18N_NOOP("Finnish translation"),"", "");
 	//Smaller frontend enhancements
@@ -185,22 +191,30 @@ int main(int argc, char* argv[]) {
 	aboutData.addCredit("Pavel Lauko",  I18N_NOOP("Czech translation"),"", "");
 	//Smaller searchdialog enhancements
 	aboutData.addCredit("Mark Lybarger",  I18N_NOOP("Searchdialog"), "mlybarge@insight.rr.com","");
+	//Polish GUI translation update
+	aboutData.addCredit("Piotr Markiewicz",  I18N_NOOP("Polish translation"), "pmarki@o2.pl", "");
 	//Smaller frontend enhancements
 	aboutData.addCredit("Luke Mauldin",  I18N_NOOP("Frontend"), "lukeskyfly@txk.net", "");
 	//translated parts of the russian website files
 	aboutData.addCredit("Igor Rykhlin",   I18N_NOOP("Russian website translation"), "", "");
+	// update to the Spanish website translation
+	aboutData.addCredit("Gabriel Pérez",   I18N_NOOP("Spanish website translation updates"), "", "");
+	//Update to the russian website translation
+	aboutData.addCredit("Igor Plisco", I18N_NOOP("Update to the russian website translation"), "", "");
 	// handbook documentation
 	aboutData.addCredit("Fred Saalbach", I18N_NOOP("Documentation"), "saalbach@sybercom.net", "");
-	//French handbook translation
-	aboutData.addCredit("Jean Van Schaftingen", I18N_NOOP("French handbook translation"), "", "");
+	// Original Russian website translator
+	aboutData.addCredit("Vlad Savitsky", I18N_NOOP("Russian website translation"), "", "");
 	// comitted search in default bible, opened modules, other smaller things
 	aboutData.addCredit("Gary Sims", I18N_NOOP("Search dialog enhancements"), "gary@garysims.co.uk", "");
 	// Very helpful testing
 	aboutData.addCredit("Wolfgang Stradner", I18N_NOOP("Very helpful and detailed testing"), "wolfgang_stradner@wycliffe.org", "");
 	//The first lead developer
 	aboutData.addCredit("Torsten Uhlmann",   I18N_NOOP("The first lead developer"), "", "");
- 	//Update of the dutch website translation(cbiblereadwindow_0)
-	aboutData.addCredit("Johan van der Lingen",   I18N_NOOP("Dutch website translation updates"), "", "");
+ 	//Update of the dutch website translation
+	aboutData.addCredit("Johan van der Lingen",   I18N_NOOP("Translation updates for the Dutch GUI, the website and the handbook"), "", "");
+	//French handbook translation
+	aboutData.addCredit("Jean Van Schaftingen", I18N_NOOP("French handbook translation"), "", "");
 	//scoped_ptr and related classes
 	aboutData.addCredit("David White",   I18N_NOOP("Helpful source code additions"), "", "http://www.wesnoth.org/");
 	//Translated the GUI into Russian
@@ -209,7 +223,8 @@ int main(int argc, char* argv[]) {
 	aboutData.addCredit("Mark Zealey",   I18N_NOOP("New Bible key choosers"), "mspam@zealey.org", "");
 	//Update to the Spanish GUI translation
  	aboutData.addCredit("Esteban Zeller",   I18N_NOOP("Spanish translation"), "", "");
-				
+
+	
 	//special message so the translator get his credits in the about box, don't remove this!
 	QString dummy = I18N_NOOP("_: NAME OF TRANSLATORS\nYour names"); //translator's name
 	dummy = I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"); //translators eMail
